@@ -1,4 +1,9 @@
 # 本次更新内容：
+# version: 1.0.5
+# 1、在draw_confusion_mat()函数中添加了是否归一化以及是否归一化与非归一化混淆矩阵都画的参数，
+#               需求说明：因为绘制归一化之后的混淆矩阵数据保存不全
+# 2、在1、的需求上有对两张混淆矩阵进行了保存是名字的修改，分别保存成"混淆矩阵.jpg"和"混淆矩阵_归一化.jpg"
+
 # version：1.0.4
 # 1、在draw_confusion_mat()函数中加入了try-except AttributeError，因为model.predict_classes()使用api创建模型时可能没有该函数
 
@@ -58,7 +63,9 @@ def draw_result(history, savepath=None):
 # 绘制混淆矩阵(用归一化之后的数据绘图)
 # 此处的plt.cm.Blues的具体颜色映射参考网址：https://matplotlib.org/gallery/color/colormap_reference.html
 def plot_confusion_matrix(cm, classes, title, savepath, normalize=False, cmap=plt.cm.Blues):
+    img_name = "混淆矩阵"
     if normalize:
+        img_name = "混淆矩阵_归一化"
         cm = cm.astype('float') / cm.sum(axis=1)[:, np.newaxis]
     plt.figure()
     plt.imshow(cm, interpolation='nearest', cmap=cmap)
@@ -70,21 +77,24 @@ def plot_confusion_matrix(cm, classes, title, savepath, normalize=False, cmap=pl
     plt.yticks(tick_marks, classes)
     plt.tick_params(axis='both', which='both', bottom=False, left=False)
     # plt.tick_params(axis='y', which='both', bottom=False)
-
     thresh = cm.max() / 2.0
-    for i, j in itertools.product(range(cm.shape[0]), range(cm.shape[1])):
-        plt.text(j, i, '{:>.4f}'.format(cm[i, j]), horizontalalignment='center',
-                 color='white' if cm[i, j] > thresh else 'black')
-
+    if normalize:
+        for i, j in itertools.product(range(cm.shape[0]), range(cm.shape[1])):
+            plt.text(j, i, '{:>.4f}'.format(cm[i, j]), horizontalalignment='center',
+                     color='white' if cm[i, j] > thresh else 'black')
+    else:
+        for i, j in itertools.product(range(cm.shape[0]), range(cm.shape[1])):
+            plt.text(j, i, cm[i, j], horizontalalignment='center',
+                     color='white' if cm[i, j] > thresh else 'black')
     # plt.tight_layout()
     plt.ylabel('True label')
     plt.xlabel('Predict label')
-    plt.savefig(savepath + '混淆矩阵.jpg', dpi=200, bbox_inches='tight')
+    plt.savefig(savepath + img_name + '.jpg', dpi=200, bbox_inches='tight')
     plt.show()
 
 
 # 整理绘制混淆矩阵所需的数据
-def draw_confusion_mat(model, test_features, test_labels, classes, savepath):
+def draw_confusion_mat(model, test_features, test_labels, classes, savepath,normalize=True,istwo=True):
     try:
         test_labels_predict = model.predict_classes(test_features)  # shape(1094,20)
     except AttributeError:
@@ -96,8 +106,9 @@ def draw_confusion_mat(model, test_features, test_labels, classes, savepath):
     # 画混淆矩阵
     confusion_mat = confusion_matrix(test_labels_true, test_labels_predict)
     # self.plot_confusion_matrix(confusion_mat, classes=range(5), title=f'Confusion matrix {class_dict}', normalize=True)
-    plot_confusion_matrix(confusion_mat, classes, savepath=savepath, title=f'Confusion matrix', normalize=True)
-
+    plot_confusion_matrix(confusion_mat, classes, savepath=savepath, title=f'Confusion matrix', normalize=normalize)
+    if istwo:
+        plot_confusion_matrix(confusion_mat, classes, savepath=savepath, title=f'Confusion matrix', normalize=not normalize)
 
 # 将样本转为one_hot形式，labels为（seample，1）或（seample,),dimension默认为2，也就是转成one_hot之后会有几列（几类）
 # begin为labels中开始的下表，例如，labels：（1,2,3,1,3,2,1,2）其中为3分类的话dimension为3，而begin为1.
